@@ -89,7 +89,6 @@ class CactusClientTest(unittest.TestCase):
         self.assertEqual(tx1.gasLimit, "1500000")
         self.assertEqual(tx1.nonce, "4")
         self.assertEqual(tx1.from_, "0xA7f5D02E141c5DF8A987833E01E4f0922A91cF29")
-        self.assertEqual(tx1.from_, "0xA7f5D02E141c5DF8A987833E01E4f0922A91cF29")
         self.assertEqual(tx1.signature, None)
 
     @mock.patch('requests.post', side_effect=mock_cactus_requests_post)
@@ -101,7 +100,7 @@ class CactusClientTest(unittest.TestCase):
             to="0xF4312f38f1139C2aa1c1dA54EF38F9ef1628dcB9",
             gasLimit="1500000",
             value="10000",
-            data="",
+            data="0x0",
             gasPrice="1000000008",
             maxFeePerGas=None,
             maxPriorityFeePerGas=None
